pub struct Progress {
pub remaining: c_int,
pub pagecount: c_int,
}Expand description
feature = "backup" Struct specifying the progress of a backup. The
percentage completion can be calculated as (pagecount - remaining) / pagecount. The progress of a backup is as of the last call to step - if
the source database is modified after a call to step, the progress value
will become outdated and potentially incorrect.
Fields
remaining: c_intNumber of pages in the source database that still need to be backed up.
pagecount: c_intTotal number of pages in the source database.