pub struct ColumnMetadata<'stmt> { /* private fields */ }Available on crate feature
column_metadata only.Expand description
Metadata about the origin of a column of a SQLite query
Implementations
Sourceimpl ColumnMetadata<'_>
impl ColumnMetadata<'_>
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
Returns the database name from which the column originates
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
Returns the table name from which the column originates
Sourcepub fn origin_name(&self) -> Option<&str>
pub fn origin_name(&self) -> Option<&str>
Returns the column name from which the column originates