Updates

Struct Updates 

pub struct Updates<'a> { /* private fields */ }
Available on crate feature vtab only.
Wrapper to UpdateVTab::update arguments

Implementations

Source

impl Updates<'_>

pub fn no_change(&self, idx: usize) -> bool

Returns true if and only

  • if the column corresponding to idx is unchanged by the UPDATE operation that the UpdateVTab::update method call was invoked to implement
  • and if and the prior VTabCursor::column method call that was invoked to extract the value for that column returned without setting a result.
pub unsafe fn on_conflict(&self, db: *mut sqlite3) -> ConflictMode

Determine the virtual table conflict policy

Safety

This function is unsafe because it uses raw pointer

Methods from Deref<Target = Values<'a>>

pub fn len(&self) -> usize

Returns the number of values.

pub fn is_empty(&self) -> bool

Returns true if there is no value.

pub fn get<T: FromSql>(&self, idx: usize) -> Result<T>

Returns value at idx

pub unsafe fn get_pointer<'a, T: 'static>( &self, idx: usize, ptr_type: &'static CStr, ) -> Option<&'a T>

Available on crate feature pointer only.

Return raw pointer at idx

Safety

This function is unsafe because it uses raw pointer and cast

pub fn iter(&self) -> ValueIter<'_>

Turns Values into an iterator.