Context

Struct Context 

pub struct Context<'a> { /* private fields */ }
Available on crate feature functions only.
Context is a wrapper for the SQLite function evaluation context.

Implementations

Source

impl Context<'_>

pub fn len(&self) -> usize

Returns the number of arguments to the function.

pub fn is_empty(&self) -> bool

Returns true when there is no argument.

pub fn get<T: FromSql>(&self, idx: usize) -> Result<T>

Returns the idxth argument as a T.

Failure

Will panic if idx is greater than or equal to self.len().

Will return Err if the underlying SQLite type cannot be converted to a T.

pub unsafe fn get_pointer<T: 'static>( &self, idx: usize, ptr_type: &'static CStr, ) -> Option<&T>

Available on crate feature pointer only.

Return raw pointer at idx

Safety

This function is unsafe because it uses raw pointer and cast

pub fn get_raw(&self, idx: usize) -> ValueRef<'_>

Returns the idxth argument as a ValueRef.

Failure

Will panic if idx is greater than or equal to self.len().

pub fn get_arg(&self, idx: usize) -> SqlFnArg

Returns the idxth argument as a SqlFnArg. To be used when the SQL function result is one of its arguments.

pub fn get_subtype(&self, idx: usize) -> c_uint

Returns the subtype of idxth argument.

Failure

Will panic if idx is greater than or equal to self.len().

pub fn get_or_create_aux<T, E, F>(&self, arg: c_int, func: F) -> Result<Arc<T>>
where T: Send + Sync + 'static, E: Into<Box<dyn Error + Send + Sync + 'static>>, F: FnOnce(ValueRef<'_>) -> Result<T, E>,

Fetch or insert the auxiliary data associated with a particular parameter. This is intended to be an easier-to-use way of fetching it compared to calling get_aux and set_aux separately.

See https://www.sqlite.org/c3ref/get_auxdata.html for a discussion of this feature, or the unit tests of this module for an example.

Failure

Will panic if arg is greater than or equal to self.len().

pub fn set_aux<T: Send + Sync + 'static>( &self, arg: c_int, value: T, ) -> Result<Arc<T>>

Sets the auxiliary data associated with a particular parameter. See https://www.sqlite.org/c3ref/get_auxdata.html for a discussion of this feature, or the unit tests of this module for an example.

Failure

Will panic if arg is greater than or equal to self.len().

pub fn get_aux<T: Send + Sync + 'static>( &self, arg: c_int, ) -> Result<Option<Arc<T>>>

Gets the auxiliary data that was associated with a given parameter via set_aux. Returns Ok(None) if no data has been associated, and Ok(Some(v)) if it has. Returns an error if the requested type does not match.

Failure

Will panic if arg is greater than or equal to self.len().

pub unsafe fn get_connection(&self) -> Result<ConnectionRef<'_>>

Get the db connection handle via sqlite3_context_db_handle

Safety

This function is marked unsafe because there is a potential for other references to the connection to be sent across threads, see this comment.