#[non_exhaustive]pub enum TraceEvent<'s> {
Stmt(StmtRef<'s>, &'s str),
Profile(StmtRef<'s>, Duration),
Row(StmtRef<'s>),
Close(ConnRef<'s>),
}Available on crate feature
trace only.Expand description
Trace event
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Stmt(StmtRef<'s>, &'s str)
when a prepared statement first begins running and possibly at other times during the execution of the prepared statement, such as at the start of each trigger subprogram
Profile(StmtRef<'s>, Duration)
when the statement finishes
Row(StmtRef<'s>)
whenever a prepared statement generates a single row of result
Close(ConnRef<'s>)
when a database connection closes