pub struct Updates<'a> { /* private fields */ }Available on crate feature
vtab only.Expand description
Wrapper to UpdateVTab::update arguments
Implementations
Sourceimpl Updates<'_>
impl Updates<'_>
Sourcepub fn no_change(&self, idx: usize) -> bool
pub fn no_change(&self, idx: usize) -> bool
Returns true if and only
- if the column corresponding to
idxis unchanged by the UPDATE operation that theUpdateVTab::updatemethod call was invoked to implement - and if and the prior
VTabCursor::columnmethod call that was invoked to extract the value for that column returned without setting a result.
Sourcepub unsafe fn on_conflict(&self, db: *mut sqlite3) -> ConflictMode
pub unsafe fn on_conflict(&self, db: *mut sqlite3) -> ConflictMode
Determine the virtual table conflict policy
Safety
This function is unsafe because it uses raw pointer
Methods from Deref<Target = Values<'a>>